@@ -86,6 +86,7 @@ async def websocket_create(hass, connection, msg):
         vol.Required("type"): "config/auth/update",
         vol.Required("user_id"): str,
         vol.Optional("name"): str,
+        vol.Optional("is_active"): bool,
         vol.Optional("group_ids"): [str],
     }
 )
@@ -111,6 +112,16 @@ async def websocket_update(hass, connection, msg):
         )
         return
 
+    if user.is_owner and msg["is_active"] is False:
+        connection.send_message(
+            websocket_api.error_message(
+                msg["id"],
+                "cannot_deactivate_owner",
+                "Unable to deactivate owner.",
+            )
+        )
+        return
+
     msg.pop("type")
     msg_id = msg.pop("id")
 
@@ -123,8 +134,19 @@ async def websocket_update(hass, connection, msg):
 
 def _user_info(user):
     """Format a user."""
+
+    ha_username = next(
+        (
+            cred.data.get("username")
+            for cred in user.credentials
+            if cred.auth_provider_type == "homeassistant"
+        ),
+        None,
+    )
+
     return {
         "id": user.id,
+        "username": ha_username,
         "name": user.name,
         "is_owner": user.is_owner,
         "is_active": user.is_active,
