@@ -1,6 +1,4 @@
 """Demo platform for the vacuum component."""
-import logging
-
 from homeassistant.components.vacuum import (
     ATTR_CLEANED_AREA,
     STATE_CLEANING,
@@ -25,8 +23,6 @@ from homeassistant.components.vacuum import (
     VacuumEntity,
 )
 
-_LOGGER = logging.getLogger(__name__)
-
 SUPPORT_MINIMAL_SERVICES = SUPPORT_TURN_ON | SUPPORT_TURN_OFF
 
 SUPPORT_BASIC_SERVICES = (
