@@ -190,7 +190,7 @@ class DysonPureCoolLinkDevice(FanEntity):
 
     async def async_added_to_hass(self):
         """Call when entity is added to hass."""
-        self.hass.async_add_job(self._device.add_message_listener, self.on_message)
+        self._device.add_message_listener(self.on_message)
 
     def on_message(self, message):
         """Call when new messages received from the fan."""
@@ -339,9 +339,7 @@ class DysonPureCoolDevice(FanEntity):
 
     async def async_added_to_hass(self):
         """Call when entity is added to hass."""
-        self.hass.async_add_executor_job(
-            self._device.add_message_listener, self.on_message
-        )
+        self._device.add_message_listener(self.on_message)
 
     def on_message(self, message):
         """Call when new messages received from the fan."""
