@@ -4,20 +4,16 @@ import logging
 import os
 
 from aiohttp import web
-from aiohttp.web_exceptions import (
-    HTTPInternalServerError,
-    HTTPNotFound,
-    HTTPUnauthorized,
-)
+from aiohttp.web_exceptions import HTTPNotFound, HTTPUnauthorized
 import voluptuous as vol
 
 from homeassistant.auth.models import User
+from homeassistant.auth.providers import homeassistant as auth_ha
 from homeassistant.components.http import HomeAssistantView
-from homeassistant.components.http.const import KEY_HASS_USER, KEY_REAL_IP
+from homeassistant.components.http.const import KEY_HASS_USER
 from homeassistant.components.http.data_validator import RequestDataValidator
 from homeassistant.const import HTTP_OK
 from homeassistant.core import callback
-from homeassistant.exceptions import HomeAssistantError
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.typing import HomeAssistantType
 
@@ -26,21 +22,6 @@ from .const import ATTR_ADDON, ATTR_PASSWORD, ATTR_USERNAME
 _LOGGER = logging.getLogger(__name__)
 
 
-SCHEMA_API_AUTH = vol.Schema(
-    {
-        vol.Required(ATTR_USERNAME): cv.string,
-        vol.Required(ATTR_PASSWORD): cv.string,
-        vol.Required(ATTR_ADDON): cv.string,
-    },
-    extra=vol.ALLOW_EXTRA,
-)
-
-SCHEMA_API_PASSWORD_RESET = vol.Schema(
-    {vol.Required(ATTR_USERNAME): cv.string, vol.Required(ATTR_PASSWORD): cv.string},
-    extra=vol.ALLOW_EXTRA,
-)
-
-
 @callback
 def async_setup_auth_view(hass: HomeAssistantType, user: User):
     """Auth setup."""
@@ -63,8 +44,10 @@ class HassIOBaseAuth(HomeAssistantView):
         """Check if this call is from Supervisor."""
         # Check caller IP
         hassio_ip = os.environ["HASSIO"].split(":")[0]
-        if request[KEY_REAL_IP] != ip_address(hassio_ip):
-            _LOGGER.error("Invalid auth request from %s", request[KEY_REAL_IP])
+        if ip_address(request.transport.get_extra_info("peername")[0]) != ip_address(
+            hassio_ip
+        ):
+            _LOGGER.error("Invalid auth request from %s", request.remote)
             raise HTTPUnauthorized()
 
         # Check caller token
@@ -72,15 +55,6 @@ class HassIOBaseAuth(HomeAssistantView):
             _LOGGER.error("Invalid auth request from %s", request[KEY_HASS_USER].name)
             raise HTTPUnauthorized()
 
-    def _get_provider(self):
-        """Return Homeassistant auth provider."""
-        prv = self.hass.auth.get_auth_provider("homeassistant", None)
-        if prv is not None:
-            return prv
-
-        _LOGGER.error("Can't find Home Assistant auth")
-        raise HTTPNotFound()
-
 
 class HassIOAuth(HassIOBaseAuth):
     """Hass.io view to handle auth requests."""
@@ -88,23 +62,30 @@ class HassIOAuth(HassIOBaseAuth):
     name = "api:hassio:auth"
     url = "/api/hassio_auth"
 
-    @RequestDataValidator(SCHEMA_API_AUTH)
+    @RequestDataValidator(
+        vol.Schema(
+            {
+                vol.Required(ATTR_USERNAME): cv.string,
+                vol.Required(ATTR_PASSWORD): cv.string,
+                vol.Required(ATTR_ADDON): cv.string,
+            },
+            extra=vol.ALLOW_EXTRA,
+        )
+    )
     async def post(self, request, data):
         """Handle auth requests."""
         self._check_access(request)
-
-        await self._check_login(data[ATTR_USERNAME], data[ATTR_PASSWORD])
-        return web.Response(status=HTTP_OK)
-
-    async def _check_login(self, username, password):
-        """Check User credentials."""
-        provider = self._get_provider()
+        provider = auth_ha.async_get_provider(request.app["hass"])
 
         try:
-            await provider.async_validate_login(username, password)
-        except HomeAssistantError:
+            await provider.async_validate_login(
+                data[ATTR_USERNAME], data[ATTR_PASSWORD]
+            )
+        except auth_ha.InvalidAuth:
             raise HTTPUnauthorized() from None
 
+        return web.Response(status=HTTP_OK)
+
 
 class HassIOPasswordReset(HassIOBaseAuth):
     """Hass.io view to handle password reset requests."""
@@ -112,22 +93,25 @@ class HassIOPasswordReset(HassIOBaseAuth):
     name = "api:hassio:auth:password:reset"
     url = "/api/hassio_auth/password_reset"
 
-    @RequestDataValidator(SCHEMA_API_PASSWORD_RESET)
+    @RequestDataValidator(
+        vol.Schema(
+            {
+                vol.Required(ATTR_USERNAME): cv.string,
+                vol.Required(ATTR_PASSWORD): cv.string,
+            },
+            extra=vol.ALLOW_EXTRA,
+        )
+    )
     async def post(self, request, data):
         """Handle password reset requests."""
         self._check_access(request)
-
-        await self._change_password(data[ATTR_USERNAME], data[ATTR_PASSWORD])
-        return web.Response(status=HTTP_OK)
-
-    async def _change_password(self, username, password):
-        """Check User credentials."""
-        provider = self._get_provider()
+        provider = auth_ha.async_get_provider(request.app["hass"])
 
         try:
-            await self.hass.async_add_executor_job(
-                provider.data.change_password, username, password
+            await provider.async_change_password(
+                data[ATTR_USERNAME], data[ATTR_PASSWORD]
             )
-            await provider.data.async_save()
-        except HomeAssistantError:
-            raise HTTPInternalServerError()
+        except auth_ha.InvalidUser as err:
+            raise HTTPNotFound() from err
+
+        return web.Response(status=HTTP_OK)
