@@ -1,5 +1,4 @@
 """Support for HomematicIP Cloud switches."""
-import logging
 from typing import Any, Dict
 
 from homematicip.aio.device import (
@@ -13,6 +12,7 @@ from homematicip.aio.device import (
     AsyncPlugableSwitchMeasuring,
     AsyncPrintedCircuitBoardSwitch2,
     AsyncPrintedCircuitBoardSwitchBattery,
+    AsyncWiredSwitch8,
 )
 from homematicip.aio.group import AsyncExtendedLinkedSwitchingGroup, AsyncSwitchingGroup
 
@@ -20,12 +20,10 @@ from homeassistant.components.switch import SwitchEntity
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.helpers.typing import HomeAssistantType
 
-from . import DOMAIN as HMIPC_DOMAIN, HomematicipGenericDevice
-from .device import ATTR_GROUP_MEMBER_UNREACHABLE
+from . import DOMAIN as HMIPC_DOMAIN, HomematicipGenericEntity
+from .generic_entity import ATTR_GROUP_MEMBER_UNREACHABLE
 from .hap import HomematicipHAP
 
-_LOGGER = logging.getLogger(__name__)
-
 
 async def async_setup_entry(
     hass: HomeAssistantType, config_entry: ConfigEntry, async_add_entities
@@ -36,13 +34,16 @@ async def async_setup_entry(
     for device in hap.home.devices:
         if isinstance(device, AsyncBrandSwitchMeasuring):
             # BrandSwitchMeasuring inherits PlugableSwitchMeasuring
-            # This device is implemented in the light platform and will
+            # This entity is implemented in the light platform and will
             # not be added in the switch platform
             pass
         elif isinstance(
             device, (AsyncPlugableSwitchMeasuring, AsyncFullFlushSwitchMeasuring)
         ):
             entities.append(HomematicipSwitchMeasuring(hap, device))
+        elif isinstance(device, AsyncWiredSwitch8):
+            for channel in range(1, 9):
+                entities.append(HomematicipMultiSwitch(hap, device, channel=channel))
         elif isinstance(
             device,
             (
@@ -54,16 +55,16 @@ async def async_setup_entry(
             entities.append(HomematicipSwitch(hap, device))
         elif isinstance(device, AsyncOpenCollector8Module):
             for channel in range(1, 9):
-                entities.append(HomematicipMultiSwitch(hap, device, channel))
+                entities.append(HomematicipMultiSwitch(hap, device, channel=channel))
         elif isinstance(device, AsyncHeatingSwitch2):
             for channel in range(1, 3):
-                entities.append(HomematicipMultiSwitch(hap, device, channel))
+                entities.append(HomematicipMultiSwitch(hap, device, channel=channel))
         elif isinstance(device, AsyncMultiIOBox):
             for channel in range(1, 3):
-                entities.append(HomematicipMultiSwitch(hap, device, channel))
+                entities.append(HomematicipMultiSwitch(hap, device, channel=channel))
         elif isinstance(device, AsyncPrintedCircuitBoardSwitch2):
             for channel in range(1, 3):
-                entities.append(HomematicipMultiSwitch(hap, device, channel))
+                entities.append(HomematicipMultiSwitch(hap, device, channel=channel))
 
     for group in hap.home.groups:
         if isinstance(group, (AsyncExtendedLinkedSwitchingGroup, AsyncSwitchingGroup)):
@@ -73,8 +74,29 @@ async def async_setup_entry(
         async_add_entities(entities)
 
 
-class HomematicipSwitch(HomematicipGenericDevice, SwitchEntity):
-    """representation of a HomematicIP Cloud switch device."""
+class HomematicipMultiSwitch(HomematicipGenericEntity, SwitchEntity):
+    """Representation of the HomematicIP multi switch."""
+
+    def __init__(self, hap: HomematicipHAP, device, channel: int) -> None:
+        """Initialize the multi switch device."""
+        super().__init__(hap, device, channel=channel)
+
+    @property
+    def is_on(self) -> bool:
+        """Return true if switch is on."""
+        return self._device.functionalChannels[self._channel].on
+
+    async def async_turn_on(self, **kwargs) -> None:
+        """Turn the switch on."""
+        await self._device.turn_on(self._channel)
+
+    async def async_turn_off(self, **kwargs) -> None:
+        """Turn the switch off."""
+        await self._device.turn_off(self._channel)
+
+
+class HomematicipSwitch(HomematicipGenericEntity, SwitchEntity):
+    """Representation of the HomematicIP switch."""
 
     def __init__(self, hap: HomematicipHAP, device) -> None:
         """Initialize the switch device."""
@@ -94,8 +116,8 @@ class HomematicipSwitch(HomematicipGenericDevice, SwitchEntity):
         await self._device.turn_off()
 
 
-class HomematicipGroupSwitch(HomematicipGenericDevice, SwitchEntity):
-    """representation of a HomematicIP switching group."""
+class HomematicipGroupSwitch(HomematicipGenericEntity, SwitchEntity):
+    """Representation of the HomematicIP switching group."""
 
     def __init__(self, hap: HomematicipHAP, device, post: str = "Group") -> None:
         """Initialize switching group."""
@@ -136,7 +158,7 @@ class HomematicipGroupSwitch(HomematicipGenericDevice, SwitchEntity):
 
 
 class HomematicipSwitchMeasuring(HomematicipSwitch):
-    """Representation of a HomematicIP measuring switch device."""
+    """Representation of the HomematicIP measuring switch."""
 
     @property
     def current_power_w(self) -> float:
@@ -149,38 +171,3 @@ class HomematicipSwitchMeasuring(HomematicipSwitch):
         if self._device.energyCounter is None:
             return 0
         return round(self._device.energyCounter)
-
-
-class HomematicipMultiSwitch(HomematicipGenericDevice, SwitchEntity):
-    """Representation of a HomematicIP Cloud multi switch device."""
-
-    def __init__(self, hap: HomematicipHAP, device, channel: int) -> None:
-        """Initialize the multi switch device."""
-        self.channel = channel
-        super().__init__(hap, device, f"Channel{channel}")
-
-    @property
-    def name(self) -> str:
-        """Return the name of the multi switch channel."""
-        label = self._get_label_by_channel(self.channel)
-        if label:
-            return label
-        return super().name
-
-    @property
-    def unique_id(self) -> str:
-        """Return a unique ID."""
-        return f"{self.__class__.__name__}_{self.post}_{self._device.id}"
-
-    @property
-    def is_on(self) -> bool:
-        """Return true if device is on."""
-        return self._device.functionalChannels[self.channel].on
-
-    async def async_turn_on(self, **kwargs) -> None:
-        """Turn the device on."""
-        await self._device.turn_on(self.channel)
-
-    async def async_turn_off(self, **kwargs) -> None:
-        """Turn the device off."""
-        await self._device.turn_off(self.channel)
