@@ -1,6 +1,4 @@
 """Support for tracking the moon phases."""
-import logging
-
 from astral import moon
 import voluptuous as vol
 
@@ -10,8 +8,6 @@ import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 import homeassistant.util.dt as dt_util
 
-_LOGGER = logging.getLogger(__name__)
-
 DEFAULT_NAME = "Moon"
 
 STATE_FIRST_QUARTER = "first_quarter"
