@@ -66,7 +66,7 @@ class OhmconnectSensor(Entity):
     def update(self):
         """Get the latest data from OhmConnect."""
         try:
-            url = "https://login.ohmconnect.com/verify-ohm-hour/{}".format(self._ohmid)
+            url = f"https://login.ohmconnect.com/verify-ohm-hour/{self._ohmid}"
             response = requests.get(url, timeout=10)
             root = ET.fromstring(response.text)
 
