@@ -1,6 +1,5 @@
 """Support for Pilight binary sensors."""
 import datetime
-import logging
 
 import voluptuous as vol
 
@@ -17,8 +16,6 @@ from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.event import track_point_in_time
 from homeassistant.util import dt as dt_util
 
-_LOGGER = logging.getLogger(__name__)
-
 CONF_VARIABLE = "variable"
 CONF_RESET_DELAY_SEC = "reset_delay_sec"
 
