@@ -1,6 +1,4 @@
 """Support for switching devices via Pilight to on and off."""
-import logging
-
 import voluptuous as vol
 
 from homeassistant.components.switch import PLATFORM_SCHEMA, SwitchEntity
@@ -9,8 +7,6 @@ import homeassistant.helpers.config_validation as cv
 
 from .base_class import SWITCHES_SCHEMA, PilightBaseDevice
 
-_LOGGER = logging.getLogger(__name__)
-
 PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
     {vol.Required(CONF_SWITCHES): vol.Schema({cv.string: SWITCHES_SCHEMA})}
 )
