@@ -85,12 +85,12 @@ _VOLUME_MON_COND = {
 }
 
 _MONITORED_CONDITIONS = (
-    list(_SYSTEM_MON_COND.keys())
-    + list(_CPU_MON_COND.keys())
-    + list(_MEMORY_MON_COND.keys())
-    + list(_NETWORK_MON_COND.keys())
-    + list(_DRIVE_MON_COND.keys())
-    + list(_VOLUME_MON_COND.keys())
+    list(_SYSTEM_MON_COND)
+    + list(_CPU_MON_COND)
+    + list(_MEMORY_MON_COND)
+    + list(_NETWORK_MON_COND)
+    + list(_DRIVE_MON_COND)
+    + list(_VOLUME_MON_COND)
 )
 
 PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
