@@ -23,6 +23,7 @@ from homeassistant.const import (
     DATA_TERABYTES,
     DATA_YOTTABYTES,
     DATA_ZETTABYTES,
+    HTTP_OK,
 )
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
@@ -52,11 +53,11 @@ SENSOR_TYPES = {
 }
 
 ENDPOINTS = {
-    "diskspace": "http{0}://{1}:{2}/{3}api/diskspace",
-    "upcoming": "http{0}://{1}:{2}/{3}api/calendar?start={4}&end={5}",
-    "movies": "http{0}://{1}:{2}/{3}api/movie",
-    "commands": "http{0}://{1}:{2}/{3}api/command",
-    "status": "http{0}://{1}:{2}/{3}api/system/status",
+    "diskspace": "{0}://{1}:{2}/{3}api/diskspace",
+    "upcoming": "{0}://{1}:{2}/{3}api/calendar?start={4}&end={5}",
+    "movies": "{0}://{1}:{2}/{3}api/movie",
+    "commands": "{0}://{1}:{2}/{3}api/command",
+    "status": "{0}://{1}:{2}/{3}api/system/status",
 }
 
 # Support to Yottabytes for the future, why not
@@ -105,11 +106,11 @@ class RadarrSensor(Entity):
         self.port = conf.get(CONF_PORT)
         self.urlbase = conf.get(CONF_URLBASE)
         if self.urlbase:
-            self.urlbase = "{}/".format(self.urlbase.strip("/"))
+            self.urlbase = f"{self.urlbase.strip('/')}/"
         self.apikey = conf.get(CONF_API_KEY)
         self.included = conf.get(CONF_INCLUDED)
         self.days = int(conf.get(CONF_DAYS))
-        self.ssl = "s" if conf.get(CONF_SSL) else ""
+        self.ssl = "https" if conf.get(CONF_SSL) else "http"
         self._state = None
         self.data = []
         self._tz = timezone(str(hass.config.time_zone))
@@ -193,7 +194,7 @@ class RadarrSensor(Entity):
             self._state = None
             return
 
-        if res.status_code == 200:
+        if res.status_code == HTTP_OK:
             if self.type in ["upcoming", "movies", "commands"]:
                 self.data = res.json()
                 self._state = len(self.data)
