@@ -17,6 +17,7 @@ from homeassistant.const import (
     CONF_HEADERS,
     CONF_METHOD,
     CONF_NAME,
+    CONF_PARAMS,
     CONF_PASSWORD,
     CONF_RESOURCE,
     CONF_USERNAME,
@@ -51,6 +52,7 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
             ["POST", "GET", "POST_JSON"]
         ),
         vol.Optional(CONF_HEADERS): vol.Schema({cv.string: cv.string}),
+        vol.Optional(CONF_PARAMS): vol.Schema({cv.string: cv.string}),
         vol.Optional(CONF_NAME): cv.string,
         vol.Optional(CONF_TARGET_PARAMETER_NAME): cv.string,
         vol.Optional(CONF_TITLE_PARAMETER_NAME): cv.string,
@@ -75,6 +77,7 @@ def get_service(hass, config, discovery_info=None):
     resource = config.get(CONF_RESOURCE)
     method = config.get(CONF_METHOD)
     headers = config.get(CONF_HEADERS)
+    params = config.get(CONF_PARAMS)
     message_param_name = config.get(CONF_MESSAGE_PARAMETER_NAME)
     title_param_name = config.get(CONF_TITLE_PARAMETER_NAME)
     target_param_name = config.get(CONF_TARGET_PARAMETER_NAME)
@@ -97,6 +100,7 @@ def get_service(hass, config, discovery_info=None):
         resource,
         method,
         headers,
+        params,
         message_param_name,
         title_param_name,
         target_param_name,
@@ -116,6 +120,7 @@ class RestNotificationService(BaseNotificationService):
         resource,
         method,
         headers,
+        params,
         message_param_name,
         title_param_name,
         target_param_name,
@@ -129,6 +134,7 @@ class RestNotificationService(BaseNotificationService):
         self._hass = hass
         self._method = method.upper()
         self._headers = headers
+        self._params = params
         self._message_param_name = message_param_name
         self._title_param_name = title_param_name
         self._target_param_name = target_param_name
@@ -171,6 +177,7 @@ class RestNotificationService(BaseNotificationService):
             response = requests.post(
                 self._resource,
                 headers=self._headers,
+                params=self._params,
                 data=data,
                 timeout=10,
                 auth=self._auth,
@@ -180,6 +187,7 @@ class RestNotificationService(BaseNotificationService):
             response = requests.post(
                 self._resource,
                 headers=self._headers,
+                params=self._params,
                 json=data,
                 timeout=10,
                 auth=self._auth,
@@ -189,7 +197,7 @@ class RestNotificationService(BaseNotificationService):
             response = requests.get(
                 self._resource,
                 headers=self._headers,
-                params=data,
+                params=self._params.update(data),
                 timeout=10,
                 auth=self._auth,
                 verify=self._verify_ssl,
