@@ -1,13 +1,9 @@
 """Support for monitoring an SABnzbd NZB client."""
-import logging
-
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity import Entity
 
 from . import DATA_SABNZBD, SENSOR_TYPES, SIGNAL_SABNZBD_UPDATED
 
-_LOGGER = logging.getLogger(__name__)
-
 
 async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the SABnzbd sensors."""
@@ -37,7 +33,11 @@ class SabnzbdSensor(Entity):
 
     async def async_added_to_hass(self):
         """Call when entity about to be added to hass."""
-        async_dispatcher_connect(self.hass, SIGNAL_SABNZBD_UPDATED, self.update_state)
+        self.async_on_remove(
+            async_dispatcher_connect(
+                self.hass, SIGNAL_SABNZBD_UPDATED, self.update_state
+            )
+        )
 
     @property
     def name(self):
@@ -49,6 +49,7 @@ class SabnzbdSensor(Entity):
         """Return the state of the sensor."""
         return self._state
 
+    @property
     def should_poll(self):
         """Don't poll. Will be updated by dispatcher signal."""
         return False
