@@ -88,8 +88,8 @@ class SesameDevice(LockEntity):
     @property
     def device_state_attributes(self) -> dict:
         """Return the state attributes."""
-        attributes = {}
-        attributes[ATTR_DEVICE_ID] = self._device_id
-        attributes[ATTR_SERIAL_NO] = self._serial
-        attributes[ATTR_BATTERY_LEVEL] = self._battery
-        return attributes
+        return {
+            ATTR_DEVICE_ID: self._device_id,
+            ATTR_SERIAL_NO: self._serial,
+            ATTR_BATTERY_LEVEL: self._battery,
+        }
