@@ -5,13 +5,14 @@ from homeassistant.components.switch import SwitchEntity
 from homeassistant.core import callback
 
 from . import ShellyDeviceWrapper
-from .const import DATA_CONFIG_ENTRY, DOMAIN
+from .const import COAP, DATA_CONFIG_ENTRY, DOMAIN
 from .entity import ShellyBlockEntity
+from .utils import async_remove_shelly_entity
 
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up switches for device."""
-    wrapper = hass.data[DOMAIN][DATA_CONFIG_ENTRY][config_entry.entry_id]
+    wrapper = hass.data[DOMAIN][DATA_CONFIG_ENTRY][config_entry.entry_id][COAP]
 
     # In roller mode the relay blocks exist but do not contain required info
     if (
@@ -20,7 +21,22 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     ):
         return
 
-    relay_blocks = [block for block in wrapper.device.blocks if block.type == "relay"]
+    relay_blocks = []
+    for block in wrapper.device.blocks:
+        if block.type == "relay":
+            appliance_type = wrapper.device.settings["relays"][int(block.channel)].get(
+                "appliance_type"
+            )
+            if not appliance_type or appliance_type.lower() != "light":
+                relay_blocks.append(block)
+                unique_id = (
+                    f'{wrapper.device.shelly["mac"]}-{block.type}_{block.channel}'
+                )
+                await async_remove_shelly_entity(
+                    hass,
+                    "light",
+                    unique_id,
+                )
 
     if not relay_blocks:
         return
