@@ -2,7 +2,7 @@
 import logging
 
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import TEMP_CELSIUS, UNIT_PERCENTAGE
+from homeassistant.const import PERCENTAGE, TEMP_CELSIUS
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity import Entity
@@ -145,9 +145,9 @@ class TadoZoneSensor(TadoZoneEntity, Entity):
         if self.zone_variable == "temperature":
             return self.hass.config.units.temperature_unit
         if self.zone_variable == "humidity":
-            return UNIT_PERCENTAGE
+            return PERCENTAGE
         if self.zone_variable == "heating":
-            return UNIT_PERCENTAGE
+            return PERCENTAGE
         if self.zone_variable == "ac":
             return None
 
