@@ -52,25 +52,33 @@ async def async_attach_trigger(
         if not result_as_boolean(result):
             return
 
-        entity_id = event.data.get("entity_id")
-        from_s = event.data.get("old_state")
-        to_s = event.data.get("new_state")
+        entity_id = event and event.data.get("entity_id")
+        from_s = event and event.data.get("old_state")
+        to_s = event and event.data.get("new_state")
+
+        if entity_id is not None:
+            description = f"{entity_id} via template"
+        else:
+            description = "time change or manual update via template"
+
+        template_variables = {
+            "platform": platform_type,
+            "entity_id": entity_id,
+            "from_state": from_s,
+            "to_state": to_s,
+        }
+        trigger_variables = {
+            "for": time_delta,
+            "description": description,
+        }
 
         @callback
         def call_action(*_):
             """Call action with right context."""
+            nonlocal trigger_variables
             hass.async_run_hass_job(
                 job,
-                {
-                    "trigger": {
-                        "platform": "template",
-                        "entity_id": entity_id,
-                        "from_state": from_s,
-                        "to_state": to_s,
-                        "for": time_delta if not time_delta else period,
-                        "description": f"{entity_id} via template",
-                    }
-                },
+                {"trigger": {**template_variables, **trigger_variables}},
                 (to_s.context if to_s else None),
             )
 
@@ -78,18 +86,9 @@ async def async_attach_trigger(
             call_action()
             return
 
-        variables = {
-            "trigger": {
-                "platform": platform_type,
-                "entity_id": entity_id,
-                "from_state": from_s,
-                "to_state": to_s,
-            }
-        }
-
         try:
             period = cv.positive_time_period(
-                template.render_complex(time_delta, variables)
+                template.render_complex(time_delta, {"trigger": template_variables})
             )
         except (exceptions.TemplateError, vol.Invalid) as ex:
             _LOGGER.error(
@@ -97,6 +96,8 @@ async def async_attach_trigger(
             )
             return
 
+        trigger_variables["for"] = period
+
         delay_cancel = async_call_later(hass, period.seconds, call_action)
 
     info = async_track_template_result(
