@@ -1,5 +1,4 @@
 """Support for the Tesla sensors."""
-import logging
 from typing import Optional
 
 from homeassistant.components.sensor import DEVICE_CLASSES
@@ -14,8 +13,6 @@ from homeassistant.util.distance import convert
 
 from . import DOMAIN as TESLA_DOMAIN, TeslaDevice
 
-_LOGGER = logging.getLogger(__name__)
-
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up the Tesla binary_sensors by config_entry."""
