@@ -1,8 +1,6 @@
 """Common code for tplink."""
-import asyncio
-from datetime import timedelta
 import logging
-from typing import Any, Callable, List
+from typing import List
 
 from pyHS100 import (
     Discover,
@@ -15,6 +13,8 @@ from pyHS100 import (
 
 from homeassistant.helpers.typing import HomeAssistantType
 
+from .const import DOMAIN as TPLINK_DOMAIN
+
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -113,89 +113,45 @@ def get_static_devices(config_data) -> SmartDevices:
     for type_ in [CONF_LIGHT, CONF_SWITCH, CONF_STRIP, CONF_DIMMER]:
         for entry in config_data[type_]:
             host = entry["host"]
-
-            if type_ == CONF_LIGHT:
-                lights.append(SmartBulb(host))
-            elif type_ == CONF_SWITCH:
-                switches.append(SmartPlug(host))
-            elif type_ == CONF_STRIP:
-                try:
-                    ss_host = SmartStrip(host)
-                except SmartDeviceException as sde:
-                    _LOGGER.error(
-                        "Failed to setup SmartStrip at %s: %s; not retrying", host, sde
-                    )
-                    continue
-                for plug in ss_host.plugs.values():
-                    switches.append(plug)
-            # Dimmers need to be defined as smart plugs to work correctly.
-            elif type_ == CONF_DIMMER:
-                lights.append(SmartPlug(host))
-
+            try:
+                if type_ == CONF_LIGHT:
+                    lights.append(SmartBulb(host))
+                elif type_ == CONF_SWITCH:
+                    switches.append(SmartPlug(host))
+                elif type_ == CONF_STRIP:
+                    for plug in SmartStrip(host).plugs.values():
+                        switches.append(plug)
+                # Dimmers need to be defined as smart plugs to work correctly.
+                elif type_ == CONF_DIMMER:
+                    lights.append(SmartPlug(host))
+            except SmartDeviceException as sde:
+                _LOGGER.error(
+                    "Failed to setup device %s due to %s; not retrying", host, sde
+                )
     return SmartDevices(lights, switches)
 
 
-async def async_add_entities_retry(
-    hass: HomeAssistantType,
-    async_add_entities: Callable[[List[Any], bool], None],
-    objects: List[Any],
-    callback: Callable[[Any, Callable], None],
-    interval: timedelta = timedelta(seconds=60),
-):
-    """
-    Add entities now and retry later if issues are encountered.
+def add_available_devices(hass, device_type, device_class):
+    """Get sysinfo for all devices."""
 
-    If the callback throws an exception or returns false, that
-    object will try again a while later.
-    This is useful for devices that are not online when hass starts.
-    :param hass:
-    :param async_add_entities: The callback provided to a
-    platform's async_setup.
-    :param objects: The objects to create as entities.
-    :param callback: The callback that will perform the add.
-    :param interval: THe time between attempts to add.
-    :return: A callback to cancel the retries.
-    """
-    add_objects = objects.copy()
+    devices = hass.data[TPLINK_DOMAIN][device_type]
 
-    is_cancelled = False
+    if f"{device_type}_remaining" in hass.data[TPLINK_DOMAIN]:
+        devices = hass.data[TPLINK_DOMAIN][f"{device_type}_remaining"]
 
-    def cancel_interval_callback():
-        nonlocal is_cancelled
-        is_cancelled = True
+    entities_ready = []
+    devices_unavailable = []
+    for device in devices:
+        try:
+            device.get_sysinfo()
+            entities_ready.append(device_class(device))
+        except SmartDeviceException as ex:
+            devices_unavailable.append(device)
+            _LOGGER.warning(
+                "Unable to communicate with device %s: %s",
+                device.host,
+                ex,
+            )
 
-    async def process_objects_loop(delay: int):
-        if is_cancelled:
-            return
-
-        await process_objects()
-
-        if not add_objects:
-            return
-
-        await asyncio.sleep(delay)
-
-        hass.async_create_task(process_objects_loop(delay))
-
-    async def process_objects(*args):
-        # Process each object.
-        for add_object in list(add_objects):
-            # Call the individual item callback.
-            try:
-                _LOGGER.debug("Attempting to add object of type %s", type(add_object))
-                result = await hass.async_add_job(
-                    callback, add_object, async_add_entities
-                )
-            except SmartDeviceException as ex:
-                _LOGGER.debug(str(ex))
-                result = False
-
-            if result is True or result is None:
-                _LOGGER.debug("Added object")
-                add_objects.remove(add_object)
-            else:
-                _LOGGER.debug("Failed to add object, will try again later")
-
-    await process_objects_loop(interval.seconds)
-
-    return cancel_interval_callback
+    hass.data[TPLINK_DOMAIN][f"{device_type}_remaining"] = devices_unavailable
+    return entities_ready
