@@ -1,6 +1,4 @@
 """Support for IKEA Tradfri lights."""
-import logging
-
 from homeassistant.components.light import (
     ATTR_BRIGHTNESS,
     ATTR_COLOR_TEMP,
@@ -29,8 +27,6 @@ from .const import (
     SUPPORTED_LIGHT_FEATURES,
 )
 
-_LOGGER = logging.getLogger(__name__)
-
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Load Tradfri lights based on a config entry."""
