@@ -30,12 +30,12 @@ SCAN_INTERVAL = timedelta(seconds=30)
 
 # sensor_type [ description, unit, icon ]
 SENSOR_TYPES = {
-    "last_build_id": ["Last Build ID", "", "mdi:account-card-details"],
+    "last_build_id": ["Last Build ID", "", "mdi:card-account-details"],
     "last_build_duration": ["Last Build Duration", TIME_SECONDS, "mdi:timelapse"],
     "last_build_finished_at": ["Last Build Finished At", "", "mdi:timetable"],
     "last_build_started_at": ["Last Build Started At", "", "mdi:timetable"],
-    "last_build_state": ["Last Build State", "", "mdi:github-circle"],
-    "state": ["State", "", "mdi:github-circle"],
+    "last_build_state": ["Last Build State", "", "mdi:github"],
+    "state": ["State", "", "mdi:github"],
 }
 
 NOTIFICATION_ID = "travisci"
