@@ -1,6 +1,4 @@
 """Support for bandwidth sensors with UniFi clients."""
-import logging
-
 from homeassistant.components.sensor import DEVICE_CLASS_TIMESTAMP, DOMAIN
 from homeassistant.const import DATA_MEGABYTES
 from homeassistant.core import callback
@@ -10,17 +8,11 @@ import homeassistant.util.dt as dt_util
 from .const import DOMAIN as UNIFI_DOMAIN
 from .unifi_client import UniFiClient
 
-LOGGER = logging.getLogger(__name__)
-
 RX_SENSOR = "rx"
 TX_SENSOR = "tx"
 UPTIME_SENSOR = "uptime"
 
 
-async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
-    """Sensor platform doesn't support configuration through configuration.yaml."""
-
-
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up sensors for UniFi integration."""
     controller = hass.data[UNIFI_DOMAIN][config_entry.entry_id]
