@@ -1,7 +1,6 @@
 """Light platform support for yeelight."""
 from functools import partial
 import logging
-from typing import Optional
 
 import voluptuous as vol
 import yeelight
@@ -10,6 +9,7 @@ from yeelight import (
     Flow,
     RGBTransition,
     SleepTransition,
+    flows,
     transitions as yee_transitions,
 )
 from yeelight.enums import BulbType, LightType, PowerMode, SceneClass
@@ -101,6 +101,15 @@ EFFECT_WHATSAPP = "WhatsApp"
 EFFECT_FACEBOOK = "Facebook"
 EFFECT_TWITTER = "Twitter"
 EFFECT_STOP = "Stop"
+EFFECT_HOME = "Home"
+EFFECT_NIGHT_MODE = "Night Mode"
+EFFECT_DATE_NIGHT = "Date Night"
+EFFECT_MOVIE = "Movie"
+EFFECT_SUNRISE = "Sunrise"
+EFFECT_SUNSET = "Sunset"
+EFFECT_ROMANCE = "Romance"
+EFFECT_HAPPY_BIRTHDAY = "Happy Birthday"
+EFFECT_CANDLE_FLICKER = "Candle Flicker"
 
 YEELIGHT_TEMP_ONLY_EFFECT_LIST = [EFFECT_TEMP, EFFECT_STOP]
 
@@ -112,6 +121,8 @@ YEELIGHT_MONO_EFFECT_LIST = [
     EFFECT_WHATSAPP,
     EFFECT_FACEBOOK,
     EFFECT_TWITTER,
+    EFFECT_HOME,
+    EFFECT_CANDLE_FLICKER,
     *YEELIGHT_TEMP_ONLY_EFFECT_LIST,
 ]
 
@@ -124,22 +135,38 @@ YEELIGHT_COLOR_EFFECT_LIST = [
     EFFECT_FAST_RANDOM_LOOP,
     EFFECT_LSD,
     EFFECT_SLOWDOWN,
+    EFFECT_NIGHT_MODE,
+    EFFECT_DATE_NIGHT,
+    EFFECT_MOVIE,
+    EFFECT_SUNRISE,
+    EFFECT_SUNSET,
+    EFFECT_ROMANCE,
+    EFFECT_HAPPY_BIRTHDAY,
     *YEELIGHT_MONO_EFFECT_LIST,
 ]
 
 EFFECTS_MAP = {
-    EFFECT_DISCO: yee_transitions.disco,
-    EFFECT_TEMP: yee_transitions.temp,
-    EFFECT_STROBE: yee_transitions.strobe,
-    EFFECT_STROBE_COLOR: yee_transitions.strobe_color,
-    EFFECT_ALARM: yee_transitions.alarm,
-    EFFECT_POLICE: yee_transitions.police,
-    EFFECT_POLICE2: yee_transitions.police2,
-    EFFECT_CHRISTMAS: yee_transitions.christmas,
-    EFFECT_RGB: yee_transitions.rgb,
-    EFFECT_RANDOM_LOOP: yee_transitions.random_loop,
-    EFFECT_LSD: yee_transitions.lsd,
-    EFFECT_SLOWDOWN: yee_transitions.slowdown,
+    EFFECT_DISCO: flows.disco,
+    EFFECT_TEMP: flows.temp,
+    EFFECT_STROBE: flows.strobe,
+    EFFECT_STROBE_COLOR: flows.strobe_color,
+    EFFECT_ALARM: flows.alarm,
+    EFFECT_POLICE: flows.police,
+    EFFECT_POLICE2: flows.police2,
+    EFFECT_CHRISTMAS: flows.christmas,
+    EFFECT_RGB: flows.rgb,
+    EFFECT_RANDOM_LOOP: flows.random_loop,
+    EFFECT_LSD: flows.lsd,
+    EFFECT_SLOWDOWN: flows.slowdown,
+    EFFECT_HOME: flows.home,
+    EFFECT_NIGHT_MODE: flows.night_mode,
+    EFFECT_DATE_NIGHT: flows.date_night,
+    EFFECT_MOVIE: flows.movie,
+    EFFECT_SUNRISE: flows.sunrise,
+    EFFECT_SUNSET: flows.sunset,
+    EFFECT_ROMANCE: flows.romance,
+    EFFECT_HAPPY_BIRTHDAY: flows.happy_birthday,
+    EFFECT_CANDLE_FLICKER: flows.candle_flicker,
 }
 
 VALID_BRIGHTNESS = vol.All(vol.Coerce(int), vol.Range(min=1, max=100))
@@ -241,7 +268,7 @@ async def async_setup_entry(
     device_type = device.type
 
     def _lights_setup_helper(klass):
-        lights.append(klass(device, custom_effects=custom_effects))
+        lights.append(klass(device, config_entry, custom_effects=custom_effects))
 
     if device_type == BulbType.White:
         _lights_setup_helper(YeelightGenericLight)
@@ -382,9 +409,9 @@ def _async_setup_services(hass: HomeAssistant):
 class YeelightGenericLight(YeelightEntity, LightEntity):
     """Representation of a Yeelight generic light."""
 
-    def __init__(self, device, custom_effects=None):
+    def __init__(self, device, entry, custom_effects=None):
         """Initialize the Yeelight light."""
-        super().__init__(device)
+        super().__init__(device, entry)
 
         self.config = device.config
 
@@ -418,12 +445,6 @@ class YeelightGenericLight(YeelightEntity, LightEntity):
             )
         )
 
-    @property
-    def unique_id(self) -> Optional[str]:
-        """Return a unique ID."""
-
-        return self.device.unique_id
-
     @property
     def supported_features(self) -> int:
         """Flag supported features."""
@@ -478,7 +499,7 @@ class YeelightGenericLight(YeelightEntity, LightEntity):
     @property
     def custom_effects_names(self):
         """Return list with custom effects names."""
-        return list(self.custom_effects.keys())
+        return list(self.custom_effects)
 
     @property
     def light_type(self):
@@ -659,9 +680,9 @@ class YeelightGenericLight(YeelightEntity, LightEntity):
         if effect in self.custom_effects_names:
             flow = Flow(**self.custom_effects[effect])
         elif effect in EFFECTS_MAP:
-            flow = Flow(count=0, transitions=EFFECTS_MAP[effect]())
+            flow = EFFECTS_MAP[effect]()
         elif effect == EFFECT_FAST_RANDOM_LOOP:
-            flow = Flow(count=0, transitions=yee_transitions.random_loop(duration=250))
+            flow = flows.random_loop(duration=250)
         elif effect == EFFECT_WHATSAPP:
             flow = Flow(count=2, transitions=yee_transitions.pulse(37, 211, 102))
         elif effect == EFFECT_FACEBOOK:
@@ -852,14 +873,10 @@ class YeelightNightLightMode(YeelightGenericLight):
     """Representation of a Yeelight when in nightlight mode."""
 
     @property
-    def unique_id(self) -> Optional[str]:
+    def unique_id(self) -> str:
         """Return a unique ID."""
         unique = super().unique_id
-
-        if unique:
-            return unique + "-nightlight"
-
-        return None
+        return f"{unique}-nightlight"
 
     @property
     def name(self) -> str:
@@ -945,12 +962,10 @@ class YeelightAmbientLight(YeelightColorLightWithoutNightlightSwitch):
         self._light_type = LightType.Ambient
 
     @property
-    def unique_id(self) -> Optional[str]:
+    def unique_id(self) -> str:
         """Return a unique ID."""
         unique = super().unique_id
-
-        if unique:
-            return unique + "-ambilight"
+        return f"{unique}-ambilight"
 
     @property
     def name(self) -> str:
