@@ -143,6 +143,25 @@ class Opening(BinarySensor):
     DEVICE_CLASS = DEVICE_CLASS_OPENING
 
 
+@STRICT_MATCH(
+    channel_names=CHANNEL_ON_OFF,
+    manufacturers="IKEA of Sweden",
+    models=lambda model: isinstance(model, str)
+    and model is not None
+    and model.find("motion") != -1,
+)
+@STRICT_MATCH(
+    channel_names=CHANNEL_ON_OFF,
+    manufacturers="Philips",
+    models={"SML001", "SML002"},
+)
+class Motion(BinarySensor):
+    """ZHA BinarySensor."""
+
+    SENSOR_ATTR = "on_off"
+    DEVICE_CLASS = DEVICE_CLASS_MOTION
+
+
 @STRICT_MATCH(channel_names=CHANNEL_ZONE)
 class IASZone(BinarySensor):
     """ZHA IAS BinarySensor."""
