@@ -1,6 +1,4 @@
 """Closures channels module for Zigbee Home Automation."""
-import logging
-
 import zigpy.zcl.clusters.closures as closures
 
 from homeassistant.core import callback
@@ -9,8 +7,6 @@ from .. import registries
 from ..const import REPORT_CONFIG_IMMEDIATE, SIGNAL_ATTR_UPDATED
 from .base import ClientChannel, ZigbeeChannel
 
-_LOGGER = logging.getLogger(__name__)
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(closures.DoorLock.cluster_id)
 class DoorLockChannel(ZigbeeChannel):
