@@ -1,5 +1,4 @@
 """Home automation channels module for Zigbee Home Automation."""
-import logging
 from typing import Optional
 
 import zigpy.zcl.clusters.homeautomation as homeautomation
@@ -12,8 +11,6 @@ from ..const import (
 )
 from .base import ZigbeeChannel
 
-_LOGGER = logging.getLogger(__name__)
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(
     homeautomation.ApplianceEventAlerts.cluster_id
