@@ -335,12 +335,13 @@ async def async_setup_entry(hass, config_entry):
 
     Will automatically load components to support devices found on the network.
     """
-    from pydispatch import dispatcher
-
     # pylint: disable=import-error
-    from openzwave.option import ZWaveOption
-    from openzwave.network import ZWaveNetwork
     from openzwave.group import ZWaveGroup
+    from openzwave.network import ZWaveNetwork
+    from openzwave.option import ZWaveOption
+
+    # pylint: enable=import-error
+    from pydispatch import dispatcher
 
     # Merge config entry and yaml config
     config = config_entry.data
@@ -593,7 +594,7 @@ async def async_setup_entry(hass, config_entry):
     async def rename_node(service):
         """Rename a node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         name = service.data.get(const.ATTR_NAME)
         node.name = name
         _LOGGER.info("Renamed Z-Wave node %d to %s", node_id, name)
@@ -613,7 +614,7 @@ async def async_setup_entry(hass, config_entry):
         """Rename a node value."""
         node_id = service.data.get(const.ATTR_NODE_ID)
         value_id = service.data.get(const.ATTR_VALUE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         value = node.values[value_id]
         name = service.data.get(const.ATTR_NAME)
         value.label = name
@@ -629,7 +630,7 @@ async def async_setup_entry(hass, config_entry):
         """Set the polling intensity of a node value."""
         node_id = service.data.get(const.ATTR_NODE_ID)
         value_id = service.data.get(const.ATTR_VALUE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         value = node.values[value_id]
         intensity = service.data.get(const.ATTR_POLL_INTENSITY)
         if intensity == 0:
@@ -667,7 +668,7 @@ async def async_setup_entry(hass, config_entry):
     def set_config_parameter(service):
         """Set a config parameter to a node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         param = service.data.get(const.ATTR_CONFIG_PARAMETER)
         selection = service.data.get(const.ATTR_CONFIG_VALUE)
         size = service.data.get(const.ATTR_CONFIG_SIZE)
@@ -725,7 +726,7 @@ async def async_setup_entry(hass, config_entry):
         """Refresh the specified value from a node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
         value_id = service.data.get(const.ATTR_VALUE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         node.values[value_id].refresh()
         _LOGGER.info("Node %s value %s refreshed", node_id, value_id)
 
@@ -734,14 +735,14 @@ async def async_setup_entry(hass, config_entry):
         node_id = service.data.get(const.ATTR_NODE_ID)
         value_id = service.data.get(const.ATTR_VALUE_ID)
         value = service.data.get(const.ATTR_CONFIG_VALUE)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         node.values[value_id].data = value
         _LOGGER.info("Node %s value %s set to %s", node_id, value_id, value)
 
     def print_config_parameter(service):
         """Print a config parameter from a node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         param = service.data.get(const.ATTR_CONFIG_PARAMETER)
         _LOGGER.info(
             "Config parameter %s on Node %s: %s",
@@ -753,13 +754,13 @@ async def async_setup_entry(hass, config_entry):
     def print_node(service):
         """Print all information about z-wave node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         nice_print_node(node)
 
     def set_wakeup(service):
         """Set wake-up interval of a node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         value = service.data.get(const.ATTR_CONFIG_VALUE)
         if node.can_wake_up():
             for value_id in node.get_values(class_id=const.COMMAND_CLASS_WAKE_UP):
@@ -806,14 +807,14 @@ async def async_setup_entry(hass, config_entry):
     def refresh_node(service):
         """Refresh all node info."""
         node_id = service.data.get(const.ATTR_NODE_ID)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         node.refresh_info()
 
     def reset_node_meters(service):
         """Reset meter counters of a node."""
         node_id = service.data.get(const.ATTR_NODE_ID)
         instance = service.data.get(const.ATTR_INSTANCE)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         for value in node.get_values(class_id=const.COMMAND_CLASS_METER).values():
             if value.index != const.INDEX_METER_RESET:
                 continue
@@ -833,7 +834,7 @@ async def async_setup_entry(hass, config_entry):
         """Heal a node on the network."""
         node_id = service.data.get(const.ATTR_NODE_ID)
         update_return_routes = service.data.get(const.ATTR_RETURN_ROUTES)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         _LOGGER.info("Z-Wave node heal running for node %s", node_id)
         node.heal(update_return_routes)
 
@@ -841,7 +842,7 @@ async def async_setup_entry(hass, config_entry):
         """Send test messages to a node on the network."""
         node_id = service.data.get(const.ATTR_NODE_ID)
         messages = service.data.get(const.ATTR_MESSAGES)
-        node = network.nodes[node_id]
+        node = network.nodes[node_id]  # pylint: disable=unsubscriptable-object
         _LOGGER.info("Sending %s test-messages to node %s", messages, node_id)
         node.test(messages)
 
